#ifndef EPIWORLD_MODELS_HPP
#define EPIWORLD_MODELS_HPP

namespace epimodels {

    #include "init-functions.hpp"

    #include "globalevents.hpp"
    #include "sis.hpp"
    #include "sir.hpp"
    #include "seir.hpp"
    #include "surveillance.hpp"
    #include "sirconnected.hpp"
    #include "seirconnected.hpp"
    #include "sird.hpp"
    #include "sisd.hpp"
    #include "seird.hpp"
    #include "sirdconnected.hpp"
    #include "seirdconnected.hpp"
    #include "sirlogit.hpp"
    #include "diffnet.hpp"
    #include "seirmixing.hpp"
    #include "sirmixing.hpp"
    #include "measlesschool.hpp"
    #include "seirmixingquarantine.hpp"
    #include "measlesmixing.hpp"
    #include "measlesmixingriskquarantine.hpp"


}

#endif
